#wish-prompt {
    margin: 1 0;
    text-align: center;
    width: 100%;
    color: yellow;
    text-style: bold;
}

#wish-container {
    align: center middle;
    width: 80%;
    height: 10;
}

#wish-input {
    width: 100%;
}

#info-buttons-container {
    layout: horizontal;
    height: auto;
    margin: 1 0;
    align: center middle;
    width: 100%;
}

#system-info-button,
#executables-button {
    margin: 0 1;
    width: 30%;
    background: #555555;
    color: #cccccc;
    text-style: italic;
    border: solid transparent;
}

#system-info-button:hover,
#executables-button:hover {
    background: #777777;
    color: white;
    border: solid #999999;
}

#modal-container {
    width: 80%;
    height: 80%;
    border: solid green;
    background: #333333;
    padding: 1;
}

#modal-title {
    text-align: center;
    width: 100%;
    color: yellow;
    text-style: bold;
}

#basic-info {
    margin: 1 0;
    height: auto;
}

#error-info {
    margin: 1 0;
    height: auto;
}

#command-generation-response {
    background: #1e1e1e;
    color: #d4d4d4;
    padding: 1;
    margin-top: 1;
    margin-bottom: 1;
    max-height: 20;
    overflow: auto;
}

#command-generation-response-label {
    margin-top: 1;
    text-style: bold;
    color: yellow;
}

#executables-info {
    margin: 1 0;
    height: 1fr;
    overflow: auto;
}

#close-button {
    margin-top: 1;
    align: center middle;
}

#command-container {
    align: center middle;
    width: 80%;
}

#wish-text {
    margin: 1 0;
    text-align: center;
    width: 100%;
}

#confirmation-text {
    margin: 1 0;
    text-align: center;
    width: 100%;
    color: yellow;
}

#button-container {
    margin: 1 0;
    width: 100%;
    height: 3;
    align-horizontal: center;
}

Button {
    margin: 0 1;
}

#execution-container {
    align: center middle;
    width: 80%;
}

#execution-text {
    margin: 1 0;
    text-align: center;
    width: 100%;
    color: green;
}

#back-button {
    margin: 1 0;
}

.command-container {
    margin: 1 0;
    width: 100%;
    border: solid green;
    padding: 1;
}

.command-status {
    margin-left: 2;
    color: yellow;
}
